pub struct InstallResult {
pub package: PackageManifest,
pub install_path: PathBuf,
pub installed_at: DateTime<Utc>,
}Expand description
Result of installing a package.
Fields
package: PackageManifestinstall_path: PathBufinstalled_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for InstallResult
impl Clone for InstallResult
Sourcefn clone(&self) -> InstallResult
fn clone(&self) -> InstallResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstallResult
impl Debug for InstallResult
Sourceimpl<'de> Deserialize<'de> for InstallResult
impl<'de> Deserialize<'de> for InstallResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InstallResult
impl JsonSchema for InstallResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InstallResult
impl RefUnwindSafe for InstallResult
impl Send for InstallResult
impl Sync for InstallResult
impl Unpin for InstallResult
impl UnsafeUnpin for InstallResult
impl UnwindSafe for InstallResult