pub struct PackageReview {
pub package_name: String,
pub reviewer: String,
pub rating: u8,
pub comment: String,
pub created_at: DateTime<Utc>,
}Expand description
A user review of a marketplace package.
Fields
package_name: Stringreviewer: Stringrating: u8comment: Stringcreated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for PackageReview
impl Clone for PackageReview
Sourcefn clone(&self) -> PackageReview
fn clone(&self) -> PackageReview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageReview
impl Debug for PackageReview
Sourceimpl<'de> Deserialize<'de> for PackageReview
impl<'de> Deserialize<'de> for PackageReview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PackageReview
impl JsonSchema for PackageReview
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PackageReview
impl RefUnwindSafe for PackageReview
impl Send for PackageReview
impl Sync for PackageReview
impl Unpin for PackageReview
impl UnsafeUnpin for PackageReview
impl UnwindSafe for PackageReview