pub struct Machine {
pub id: String,
pub name: String,
pub transport: MachineTransport,
pub capabilities: MachineCapabilities,
pub status: MachineStatus,
pub last_heartbeat: Option<DateTime<Utc>>,
pub added_at: DateTime<Utc>,
}Expand description
A registered machine in the inventory.
Fields
id: Stringname: Stringtransport: MachineTransportcapabilities: MachineCapabilitiesstatus: MachineStatuslast_heartbeat: Option<DateTime<Utc>>added_at: DateTime<Utc>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Machine
impl<'de> Deserialize<'de> for Machine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Machine
impl JsonSchema for Machine
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Machine
impl RefUnwindSafe for Machine
impl Send for Machine
impl Sync for Machine
impl Unpin for Machine
impl UnsafeUnpin for Machine
impl UnwindSafe for Machine