pub struct MachineCapabilities {
pub os: String,
pub arch: String,
pub cpu_cores: u32,
pub memory_gb: f64,
pub gpu: Option<String>,
pub tags: Vec<String>,
pub installed_tools: Vec<String>,
}Expand description
Capabilities and resources of a remote machine.
Fields
os: Stringarch: Stringcpu_cores: u32memory_gb: f64gpu: Option<String>installed_tools: Vec<String>Trait Implementations
Sourceimpl Clone for MachineCapabilities
impl Clone for MachineCapabilities
Sourcefn clone(&self) -> MachineCapabilities
fn clone(&self) -> MachineCapabilities
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineCapabilities
impl Debug for MachineCapabilities
Sourceimpl<'de> Deserialize<'de> for MachineCapabilities
impl<'de> Deserialize<'de> for MachineCapabilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineCapabilities
impl JsonSchema for MachineCapabilities
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineCapabilities
impl RefUnwindSafe for MachineCapabilities
impl Send for MachineCapabilities
impl Sync for MachineCapabilities
impl Unpin for MachineCapabilities
impl UnsafeUnpin for MachineCapabilities
impl UnwindSafe for MachineCapabilities