pub struct RelayCommand {
pub target_machine: String,
pub command: String,
pub working_dir: Option<String>,
pub timeout_secs: u64,
}Expand description
Message sent through the relay to execute a command.
Fields
target_machine: Stringcommand: Stringworking_dir: Option<String>timeout_secs: u64Trait Implementations
Sourceimpl Clone for RelayCommand
impl Clone for RelayCommand
Sourcefn clone(&self) -> RelayCommand
fn clone(&self) -> RelayCommand
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelayCommand
impl Debug for RelayCommand
Sourceimpl<'de> Deserialize<'de> for RelayCommand
impl<'de> Deserialize<'de> for RelayCommand
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelayCommand
impl JsonSchema for RelayCommand
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelayCommand
impl RefUnwindSafe for RelayCommand
impl Send for RelayCommand
impl Sync for RelayCommand
impl Unpin for RelayCommand
impl UnsafeUnpin for RelayCommand
impl UnwindSafe for RelayCommand