pub struct RelayResponse {
pub machine_id: String,
pub stdout: String,
pub stderr: String,
pub exit_code: i32,
pub duration_ms: u64,
}Expand description
Response received from a relay command execution.
Fields
machine_id: Stringstdout: Stringstderr: Stringexit_code: i32duration_ms: u64Trait Implementations
Sourceimpl Clone for RelayResponse
impl Clone for RelayResponse
Sourcefn clone(&self) -> RelayResponse
fn clone(&self) -> RelayResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelayResponse
impl Debug for RelayResponse
Sourceimpl<'de> Deserialize<'de> for RelayResponse
impl<'de> Deserialize<'de> for RelayResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RelayResponse> for RemoteOutput
impl From<RelayResponse> for RemoteOutput
Sourcefn from(resp: RelayResponse) -> Self
fn from(resp: RelayResponse) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for RelayResponse
impl JsonSchema for RelayResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelayResponse
impl RefUnwindSafe for RelayResponse
impl Send for RelayResponse
impl Sync for RelayResponse
impl Unpin for RelayResponse
impl UnsafeUnpin for RelayResponse
impl UnwindSafe for RelayResponse