Module skill

Module skill 

Skill system — load, install, list, and manage workflow skills.

Skills are packaged workflow templates with metadata that can be installed from local directories or a community repository.

Structs

InstalledSkill
An installed skill with metadata.
ScheduleConfig
Scheduled job definition used by both skill system and scheduler.
SkillManifest
Skill manifest (skill.yaml) — metadata for a skill package.
SkillRegistry
Registry of installed skills.
SkillSummary
Skill info summary for display.
TriggerConfig
Trigger configuration used by skill system and trigger engine.

Enums

SkillSource
Where a skill was installed from.
TriggerType
Types of event triggers.

Functions

search_skills
Search skills by tag or name.