pub struct SyncConflict {
pub workflow_id: String,
pub local_version: u64,
pub remote_version: u64,
pub local_peer: String,
pub remote_peer: String,
pub detected_at: DateTime<Utc>,
}Expand description
A detected conflict between two versions of a workflow.
Fields
workflow_id: Stringlocal_version: u64remote_version: u64local_peer: Stringremote_peer: Stringdetected_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for SyncConflict
impl Clone for SyncConflict
Sourcefn clone(&self) -> SyncConflict
fn clone(&self) -> SyncConflict
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyncConflict
impl Debug for SyncConflict
Sourceimpl<'de> Deserialize<'de> for SyncConflict
impl<'de> Deserialize<'de> for SyncConflict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncConflict
impl JsonSchema for SyncConflict
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SyncConflict
impl RefUnwindSafe for SyncConflict
impl Send for SyncConflict
impl Sync for SyncConflict
impl Unpin for SyncConflict
impl UnsafeUnpin for SyncConflict
impl UnwindSafe for SyncConflict