compose_workflows

Function compose_workflows 

pub fn compose_workflows(
    base_id: &str,
    base_name: &str,
    workflows: &[Workflow],
) -> Result<ComposedWorkflow>
Compose multiple workflows into a single workflow by merging steps and variables.

Steps are concatenated in order; variables from later workflows override earlier ones unless there’s a naming conflict, in which case the child workflow’s variable is prefixed with its workflow ID.