Workflow execution engine — runs workflow steps with constitution checks, audit logging, checkpoints, and failure handling.
Structs
- Workflow
Runner - Workflow execution engine.
Workflow execution engine — runs workflow steps with constitution checks, audit logging, checkpoints, and failure handling.