Module versioning

Module versioning 

Git-based workflow version control — track, list, and restore workflow versions.

Structs

WorkflowVersion
A single version entry from the git history of a workflow file.

Functions

list_versions
List all versions (git log) for a workflow file.
restore_version
Restore a workflow file to a specific git version.
version_workflow
Auto-commit workflow changes to the git repository at ~/.mur/workflows/.