version_workflow

Function version_workflow 

pub fn version_workflow(
    workflow_id: &str,
    yaml_content: &str,
) -> Result<WorkflowVersion>
Auto-commit workflow changes to the git repository at ~/.mur/workflows/.

Creates or updates the workflow file and commits the change.