Git-based workflow version control — track, list, and restore workflow versions.
Structs
- Workflow
Version - A single version entry from the git history of a workflow file.
Functions
- list_
versions - List all versions (git log) for a workflow file.
- restore_
version - Restore a workflow file to a specific git version.
- version_
workflow - Auto-commit workflow changes to the git repository at
~/.mur/workflows/.