pub fn version_workflow(
workflow_id: &str,
yaml_content: &str,
) -> Result<WorkflowVersion>Expand description
Auto-commit workflow changes to the git repository at ~/.mur/workflows/.
Creates or updates the workflow file and commits the change.